@@ -1,5 +1,7 @@
 use crate::ffi;
 
+pub use crate::ffi::OscillatorType;
+
 pub trait AudioNode {
     fn node_id(&self) -> u32;
 
@@ -98,14 +100,6 @@ pub trait SingleValue: AudioNode {
     }
 }
 
-#[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
-pub enum OscillatorType {
-    Sine,
-    Square,
-    Sawtooth,
-    Triangle,
-}
-
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct Oscillator {
     id: u32,
@@ -122,22 +116,10 @@ impl SingleValue for Oscillator {}
 impl AudioSource for Oscillator {}
 
 impl Oscillator {
-    pub fn new() -> Self {
-        let id = unsafe { ffi::qwac_audio_oscillator() };
+    pub fn new(oscillator_type: OscillatorType) -> Self {
+        let id = unsafe { ffi::qwac_audio_oscillator(oscillator_type) };
         Self { id }
     }
-
-    pub fn set_type(&mut self, type_: OscillatorType) {
-        unsafe {
-            match type_ {
-                OscillatorType::Sine => ffi::qwac_audio_oscillator_sine(self.node_id()),
-
-                OscillatorType::Square => ffi::qwac_audio_oscillator_square(self.node_id()),
-                OscillatorType::Sawtooth => ffi::qwac_audio_oscillator_sawtooth(self.node_id()),
-                OscillatorType::Triangle => ffi::qwac_audio_oscillator_triangle(self.node_id()),
-            }
-        }
-    }
 }
 
 impl Drop for Oscillator {
