@@ -1,5 +1,6 @@
 use crate::texture::Texture;
 use crate::{ffi, Color, Rectangle};
+pub use crate::ffi::CompositeOperation;
 
 #[derive(Debug)]
 pub struct Canvas {
@@ -60,9 +61,38 @@ impl Canvas {
         }
     }
 
+    pub fn draw_canvas(&self, canvas: &Canvas, source: Rectangle, destination: Rectangle) {
+        unsafe {
+            ffi::qwac_canvas_draw_canvas(
+                self.id,
+                canvas.id,
+                source.x,
+                source.y,
+                source.width,
+                source.height,
+                destination.x,
+                destination.y,
+                destination.width,
+                destination.height,
+            );
+        }
+    }
+
     pub fn as_texture(&self) -> Texture {
         Texture::from_canvas(self)
     }
+
+    pub fn set_global_alpha(&self, alpha: f64) {
+        unsafe {
+            ffi::qwac_canvas_set_global_alpha(self.id, alpha);
+        }
+    }
+
+    pub fn set_global_composite_operation(&self, operation: CompositeOperation) {
+        unsafe {
+            ffi::qwac_canvas_set_global_composite_operation(self.id, operation);
+        }
+    }
 }
 
 impl Drop for Canvas {
