@@ -32,6 +32,35 @@ pub struct Color {
     pub a: u8,
 }
 
+impl Color {
+    pub fn white() -> Color {
+        Color {
+            r: u8::MAX,
+            g: u8::MAX,
+            b: u8::MAX,
+            a: u8::MAX,
+        }
+    }
+
+    pub fn black() -> Color {
+        Color {
+            r: u8::MIN,
+            g: u8::MIN,
+            b: u8::MIN,
+            a: u8::MAX,
+        }
+    }
+
+    pub fn clear() -> Color {
+        Color {
+            r: u8::MIN,
+            g: u8::MIN,
+            b: u8::MIN,
+            a: u8::MIN,
+        }
+    }
+}
+
 pub trait Game {
     /// Create a new Game of this type, starting at the given time in seconds.
     fn new(timestamp: f64) -> Self;
